@@ -7,6 +7,12 @@ NULL
 #' @import ggplot2
 #' @export
 facet_rep_wrap <- function(..., scales = 'fixed', repeat.tick.labels=FALSE) {
+  .Deprecated(
+    package = "lemon",
+    msg = paste0("`facet_rep_wrap` and `facet_rep_lab` have been soft-deprecated. ",
+      "A replacement can be found in ggh4x::facet_wrap2.")
+  )
+
   f <- facet_wrap(scales=scales, ...)
 
   rtl <- reduce.ticks.labels.settings(repeat.tick.labels)
@@ -90,9 +96,9 @@ FacetWrapRepeatLabels <- ggplot2::ggproto('FacetWrapRepeatLabels',
     panel_table$layout$name <- paste0('panel-', rep(seq_len(ncol), nrow), '-', rep(seq_len(nrow), each = ncol))
 
     panel_table <- gtable::gtable_add_col_space(panel_table,
-      theme$panel.spacing.x %||% theme$panel.spacing)
+      calc_element("panel.spacing.x", theme))
     panel_table <- gtable::gtable_add_row_space(panel_table,
-      theme$panel.spacing.y %||% theme$panel.spacing)
+      calc_element("panel.spacing.y", theme))
 
     # Add axes
     axis_mat_x_top <- empty_table
@@ -103,19 +109,11 @@ FacetWrapRepeatLabels <- ggplot2::ggproto('FacetWrapRepeatLabels',
     axis_mat_y_left[panel_pos] <- axes$y$left[layout$SCALE_Y]
     axis_mat_y_right <- empty_table
     axis_mat_y_right[panel_pos] <- axes$y$right[layout$SCALE_Y]
-    #if (!params$free$x) {
-    #  axis_mat_x_top[-1,]<- list(zeroGrob())
-    #  axis_mat_x_bottom[-nrow,]<- list(zeroGrob())
-    #}
-    #if (!params$free$y) {
-    #  axis_mat_y_left[, -1] <- list(zeroGrob())
-    #  axis_mat_y_right[, -ncol] <- list(zeroGrob())
-    #}
 
-    if (!'top' %in% params$repeat.tick.labels)  axis_mat_x_top[-1,] <- lapply(axis_mat_x_top[-1,], remove_labels_from_axis, 'horizontal')
-    if (!'bottom' %in% params$repeat.tick.labels)  axis_mat_x_bottom[-nrow,] <- lapply(axis_mat_x_bottom[-nrow,], remove_labels_from_axis, 'horizontal')
-    if (!'left' %in% params$repeat.tick.labels)  axis_mat_y_left[,-1] <- lapply(axis_mat_y_left[,-1], remove_labels_from_axis, 'vertical')
-    if (!'right' %in% params$repeat.tick.labels)  axis_mat_y_right[, -ncol] <- lapply(axis_mat_y_right[, -ncol], remove_labels_from_axis, 'vertical')
+    if (!'top' %in% params$repeat.tick.labels)  axis_mat_x_top[-1,] <- lapply(axis_mat_x_top[-1,], remove_labels_from_axis)
+    if (!'bottom' %in% params$repeat.tick.labels)  axis_mat_x_bottom[-nrow,] <- lapply(axis_mat_x_bottom[-nrow,], remove_labels_from_axis)
+    if (!'left' %in% params$repeat.tick.labels)  axis_mat_y_left[,-1] <- lapply(axis_mat_y_left[,-1], remove_labels_from_axis)
+    if (!'right' %in% params$repeat.tick.labels)  axis_mat_y_right[, -ncol] <- lapply(axis_mat_y_right[, -ncol], remove_labels_from_axis)
 
     axis_height_top <- unit(apply(axis_mat_x_top, 1, max_height), "cm")
     axis_height_bottom <- unit(apply(axis_mat_x_bottom, 1, max_height), "cm")
